Constants class
Clas with constants for usage in app
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- appraisalEndPoint → const String
- attendanceRequestEndPoint → const String
- attendancesEndPoint → const String
- employeeAdvanceEndPoint → const String
- employeeCheckInEndPoint → const String
- employeeDetailsEndPoint → const String
- employeePerformanceFeedbackEndPoint → const String
- employeePromotionEndPoint → const String
- expenseClaimEndPoint → const String
- goalsEndPoint → const String
- grievanceEndPoint → const String
- holidayListEndPoint → const String
- leaveAllotmentEndPoint → const String
- leaveApplicationsEndPoint → const String
- leaveEncashmentEndPoint → const String
- loginEndPoint → const String
- permissionsEndPoint → const String
- referralEndPoint → const String
- shiftRequestEndPoint → const String
- trainingEventEndPoint → const String
- trainingFeedbackEndPoint → const String
- trainingProgramEndPoint → const String
- travelRequestEndPoint → const String