ERPNextAPI class

Class for handling API calls

Constructors

ERPNextAPI(String baseUrl)

Properties

baseUrl String
getter/setter pair
cookieHeader String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createUri(String url, [Map<String, Object>? queryParameters]) Uri
This function is for getting the URI
getAdvanceSummary(String employeeId, String company, Function successCallback, Function failureCallback) Future<void>
getAppraisalOverview(String employeeId, Function successCallback, Function failureCallback) Future<void>
getAppraisals(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee appraisals
getAttendanceRequest(String employeeId, Function successCallback, Function failureCallback) Future<void>
getAttendances(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee attendance
getEmployeeAdvance(String employeeId, Function successCallback, Function failureCallback) Future<void>
getEmployeeCheckIn(String employeeId, Function successCallback, Function failureCallback) Future<void>
getEmployeeDetails(String userId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee details
getEmployeePromotion(String employeeId, Function successCallback, Function failureCallback) Future<void>
getExpenseClaims(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee expense claims
getGoals(String employeeId, Function successCallback, Function failureCallback) Future<void>
getGrievance(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee grievances
getHolidayList(Function successCallback, Function failureCallback) Future<void>
getLeaveAllotment(String employeeId, Function successCallback, Function failureCallback) Future<void>
getLeaveApplications(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee leave applications
getLeaveBalanceReport(String employeeId, String fromDate, String toDate, Function successCallback, Function failureCallback) Future<void>
getLeaveBalanceSummary(String employeeId, String company, String date, Function successCallback, Function failureCallback) Future<void>
getLeaveEncashment(String employeeId, Function successCallback, Function failureCallback) Future<void>
getPerformanceFeedback(String employeeId, Function successCallback, Function failureCallback) Future<void>
getReferrals(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee referrals
getShiftAttendance(String employeeId, Function successCallback, Function failureCallback) Future<void>
getShiftRequest(String employeeId, Function successCallback, Function failureCallback) Future<void>
getTrainingEvent(Function successCallback, Function failureCallback) Future<void>
getTrainingFeedback(String employeeId, Function successCallback, Function failureCallback) Future<void>
getTrainingProgram(Function successCallback, Function failureCallback) Future<void>
getTravelRequest(String employeeId, Function successCallback, Function failureCallback) Future<void>
login(String userName, String password, Function successCallback, Function failureCallback) Future<void>
This function is for logging into the ERPNext instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited