AdvanceSummaryModel class

Constructors

AdvanceSummaryModel(String title, String employee, String company, String postingDate, double advanceAmount, double paidAmount, double claimedAmount, String status, String currency)
AdvanceSummaryModel.fromJson(Map<String, dynamic> json)
factory

Properties

advanceAmount double
getter/setter pair
claimedAmount double
getter/setter pair
company String
getter/setter pair
currency String
getter/setter pair
employee String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
paidAmount double
getter/setter pair
postingDate String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
title String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited