AttendanceModel class

Class for handling attendance data

Constructors

AttendanceModel(String name, String employeeName, String status, String attendanceDate)
AttendanceModel.fromJson(Map<String, dynamic> json)
Function for converting json to object
factory

Properties

attendanceDate String
getter/setter pair
employeeName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited