AttendanceRequestModel class

Constructors

AttendanceRequestModel(String name, String employeeName, String fromDate, String toDate, String reason)
AttendanceRequestModel.fromJson(Map<String, dynamic> json)
factory

Properties

employeeName String
getter/setter pair
fromDate String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
reason String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited