GoalModel class

Constructors

GoalModel(String name, String employeeName, String goalName, String status, String startDate, double progress)
GoalModel.fromJson(Map<String, dynamic> json)
factory

Properties

employeeName String
getter/setter pair
goalName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
progress double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startDate String
getter/setter pair
status String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited