PerformanceFeedbackModel class
Constructors
- PerformanceFeedbackModel(String name, String employeeName, String reviewerName, String addedOn, String appraisal, String feedback)
-
PerformanceFeedbackModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- addedOn ↔ String
-
getter/setter pair
- appraisal ↔ String
-
getter/setter pair
- employeeName ↔ String
-
getter/setter pair
- feedback ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
getter/setter pair
- reviewerName ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited