PromotionModel class

Constructors

PromotionModel(String name, String employeeName, String promotionDate, double currentCtc, double revisedCtc)
PromotionModel.fromJson(Map<String, dynamic> json)
factory

Properties

currentCtc double
getter/setter pair
employeeName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
promotionDate String
getter/setter pair
revisedCtc double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited