ShiftAttendanceModel class

Constructors

ShiftAttendanceModel(String name, String employee, String employeeName, String shift, String attendanceDate, String status, String shiftStart, String shiftEnd, String inTime, String outTime, double workingHours, double lateEntryHrs, double earlyExitHrs, String department, String company, String shiftActualStart, String shiftActualEnd)
ShiftAttendanceModel.fromJson(Map<String, dynamic> json)
factory

Properties

attendanceDate String
getter/setter pair
company String
getter/setter pair
department String
getter/setter pair
earlyExitHrs double
getter/setter pair
employee String
getter/setter pair
employeeName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inTime String
getter/setter pair
lateEntryHrs double
getter/setter pair
name String
getter/setter pair
outTime String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift String
getter/setter pair
shiftActualEnd String
getter/setter pair
shiftActualStart String
getter/setter pair
shiftEnd String
getter/setter pair
shiftStart String
getter/setter pair
status String
getter/setter pair
workingHours double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited