ShiftRequestModel class

Constructors

ShiftRequestModel(String name, String employeeName, String shiftType, String status, String approver, String fromDate, String toDate)
ShiftRequestModel.fromJson(Map<String, dynamic> json)
factory

Properties

approver String
getter/setter pair
employeeName String
getter/setter pair
fromDate String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shiftType String
getter/setter pair
status String
getter/setter pair
toDate String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited