TrainingEventModel class

Constructors

TrainingEventModel(String eventName, String trainingProgram, String type, String eventStatus, String location, String startTime, String endTime, String introduction)
TrainingEventModel.fromJson(Map<String, dynamic> json)
factory

Properties

endTime String
getter/setter pair
eventName String
getter/setter pair
eventStatus String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
introduction String
getter/setter pair
location String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String
getter/setter pair
trainingProgram String
getter/setter pair
type String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited