TrainingProgramModel class

Constructors

TrainingProgramModel(String name, String status, String trainerName, String description)
TrainingProgramModel.fromJson(Map<String, dynamic> json)
factory

Properties

description String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
getter/setter pair
trainerName String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited