CheckInModel class

Constructors

CheckInModel(String name, String employeeName, String time, String deviceId, String logType, String shift, String attendance)
CheckInModel.fromJson(Map<String, dynamic> json)
factory

Properties

attendance String
getter/setter pair
deviceId String
getter/setter pair
employeeName String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
logType String
getter/setter pair
name String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift String
getter/setter pair
time String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited