ERPNextAPI class

Class for handling API calls

Constructors

ERPNextAPI(String baseUrl)

Properties

baseUrl String
getter/setter pair
cookieHeader String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAppraisals(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee appraisals
getAttendances(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee attendance
getEmployeeDetails(String userId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee details
getExpenseClaims(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee expense claims
getGrievance(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee grievances
getLeaveApplications(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee leave applications
getReferrals(String employeeId, Function successCallback, Function failureCallback) Future<void>
Function for getting employee referrals
login(String userName, String password, Function successCallback, Function failureCallback) Future<void>
This function is for logging into the ERPNext instance
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited