LeaveBalanceReportModel class
Constructors
Properties
- closingBalance ↔ double
-
getter/setter pair
- employee ↔ String
-
getter/setter pair
- employeeName ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- indent ↔ int
-
getter/setter pair
- leavesAllocated ↔ double
-
getter/setter pair
- leavesExpired ↔ double
-
getter/setter pair
- leavesTaken ↔ double
-
getter/setter pair
- leaveType ↔ String
-
getter/setter pair
- openingBalance ↔ double
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited